QUEUE_NAME = 'queue'
QUEUE_CONCURRENCY = 10
QUEUE_MAX_ATTEMP = 3
